@@ -72,6 +72,33 @@ GSList * imageinfo_sort (GSList *gsl_iinfo)
     return g_slist_sort (gsl_iinfo, (GCompareFunc) compare_imageitems);
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Remove duplicates from ImageInfo list.
+ */
+GSList * imageinfo_remove_duplicates (GSList *gsl_iinfo)
+{
+    GSList *gsl_itr = NULL;
+    GSList *gsl_nxt = NULL;
+    GSList *gsl_act = NULL;
+
+    for (gsl_itr = gsl_iinfo; gsl_itr; gsl_itr = gsl_itr->next) {
+        gsl_nxt = gsl_itr->next;
+
+        while (gsl_nxt) {
+
+            gsl_act = gsl_nxt;
+
+            gsl_nxt = gsl_nxt->next;
+
+            if (compare_imageitems (gsl_itr->data, gsl_act->data) == 0) {
+                gsl_iinfo = g_slist_remove_link (gsl_iinfo, gsl_act);
+                imageinfo_free (gsl_act->data);
+            }
+        }
+    }
+    return gsl_iinfo;
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Get file info and put it in a ImageInfo object.
  */
@@ -275,9 +302,8 @@ imageinfo_get_height (const ImageInfo *ii_info)
  * @brief  Get string with image dimensions (width x height)
  */
 const char *
-imageinfo_get_wxh (const ImageInfo *ii_info)
+imageinfo_get_wxh (ImageInfo *ii_info)
 {
-
     char s_tmp[40]; /* Temp string, I think it is long enough */
 
     memset (s_tmp, 0, sizeof(s_tmp));
