@@ -39,24 +39,6 @@ hash(const char *str)
     return hash;
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get file extenstion.
- */
-char *
-get_file_ext (const char *s_fn)
-{
-    char *s_ext = NULL; /* Extension string */
-    char *s_p   = NULL; /* Pointer to first right . */
-
-    s_p = strrchr (s_fn, '.');
-    if (s_p != NULL) {
-        s_ext = s_p+1;
-        //s_p++;
-        //s_ext = str_dup (s_p);
-    }
-    return s_ext;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Create or resize dynamic array
  */
@@ -111,11 +93,12 @@ str_ndup (const char *s_str,
     if (s_str == NULL)
         return NULL;
 
-    create_resize ((void**) &s_res, st_len, sizeof (char));
+    create_resize ((void**) &s_res, st_len+1, sizeof (char));
     //s_res = calloc (st_len, sizeof (char));
     //if (s_res == NULL)
     //    return NULL;
 
+    //strcpy (s_res, s_str);
     memcpy (s_res, s_str, st_len);
 
     return s_res;
@@ -127,7 +110,7 @@ str_ndup (const char *s_str,
 char *
 str_dup (const char *s_str)
 {
-    return str_ndup (s_str, strlen (s_str) + 1);
+    return str_ndup (s_str, strlen (s_str));
 }
 /*----------------------------------------------------------------------------*/
 /**
