@@ -42,7 +42,7 @@ settings_write (WallSett *ws_sett)
 }
 /*----------------------------------------------------------------------------*/
 /**
- * @brief  Update last used wallpaper position in program settings. 
+ * @brief  Update last used wallpaper position in config file. 
  */
 int
 settings_update_last_used (WallSett *ws_sett)
@@ -51,6 +51,18 @@ settings_update_last_used (WallSett *ws_sett)
                                          settings_get_cfg_fn (ws_sett));
 }
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Update window size in config file. 
+ */
+int
+settings_update_window_size (WallSett *ws_sett,
+                             const int i_w,
+                             const int i_h)
+{
+    return js_settings_update_window_size (settings_get_cfg_fn (ws_sett),
+                                           i_w, i_h);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Check if settings are different that saved ones.
  */
