@@ -19,9 +19,9 @@
  *
  * Program to change wallpapers.
  *
- * @date November 15, 2019
+ * @date November 17, 2019
  *
- * @version 1.2.1
+ * @version 1.2.2
  * 
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
@@ -50,8 +50,8 @@ main (int    argc,
 {
     WallSett  ws_sett;
     uint32_t  ui_cnt = 0;
-    
-    if (settings_init (&ws_sett)) {
+
+    if (settings_init (&ws_sett) != ERR_OK) {
         settings_free (&ws_sett);
         exit (EXIT_FAILURE);
     }
@@ -65,6 +65,7 @@ main (int    argc,
         exit (EXIT_FAILURE);
     }
 
+    /* Set the maximun random range to the length of the file list */
     randomm_set_range (&ws_sett.rm_mem, flist_get_len (&ws_sett.fl_files));
 
     if (wallpaper_startup_set (&ws_sett) != ERR_OK) {
